X-Git-Url: https://git.rapsys.eu/userbundle/blobdiff_plain/bab59a4b88a081a7a27a53b4559d74e63b68db92..6699a79d7f3e958907a0f580e4685b95be79296c:/Entity/Group.php

diff --git a/Entity/Group.php b/Entity/Group.php
index c7000ea..c97515c 100644
--- a/Entity/Group.php
+++ b/Entity/Group.php
@@ -1,9 +1,25 @@
-<?php
+<?php declare(strict_types=1);
+
+/*
+ * This file is part of the Rapsys UserBundle package.
+ *
+ * (c) Raphaël Gertz <symfony@rapsys.eu>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
 
-// src/Rapsys/UserBundle/Entity/Group.php
 namespace Rapsys\UserBundle\Entity;
 
-class Group extends \Symfony\Component\Security\Core\Role\Role {
+use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\ORM\Event\PreUpdateEventArgs;
+
+use Rapsys\UserBundle\Entity\User;
+
+/**
+ * Group
+ */
+class Group {
 	/**
 	 * @var integer
 	 */
@@ -12,7 +28,7 @@ class Group extends \Symfony\Component\Security\Core\Role\Role {
 	/**
 	 * @var string
 	 */
-	protected $role;
+	protected $title;
 
 	/**
 	 * @var \DateTime
@@ -25,39 +41,52 @@ class Group extends \Symfony\Component\Security\Core\Role\Role {
 	protected $updated;
 
 	/**
-	 * @var \Doctrine\Common\Collections\Collection
+	 * @var ArrayCollection
 	 */
 	protected $users;
 
 	/**
 	 * Constructor
 	 * @param string $role The role name
 	 */
-	public function __construct($role) {
-		$this->role = (string) $role;
-		$this->users = new \Doctrine\Common\Collections\ArrayCollection();
+	public function __construct(string $title) {
+		//Set defaults
+		$this->title = $title;
+		$this->created = new \DateTime('now');
+		$this->updated = new \DateTime('now');
+		$this->users = new ArrayCollection();
 	}
 
 	/**
-	 * Set role
+	 * Get id
 	 *
-	 * @param string $role
+	 * @return integer
+	 */
+	public function getId(): int {
+		return $this->id;
+	}
+
+	/**
+	 * Set title
 	 *
-	 * @return User
+	 * @param string $title The group name
+	 *
+	 * @return Group
 	 */
-	public function setRole($role) {
-		$this->role = $role;
+	public function setTitle(string $title): Group {
+		$this->title = $title;
 
 		return $this;
 	}
 
 	/**
-	 * Get role
+	 * Get title
 	 *
 	 * @return string
 	 */
-	public function getRole() {
-		return $this->role;
+	public function getTitle(): ?string {
+		return $this->title;
 	}
 
 	/**
@@ -65,9 +94,9 @@ class Group extends \Symfony\Component\Security\Core\Role\Role {
 	 *
 	 * @param \DateTime $created
 	 *
-	 * @return User
+	 * @return Group
 	 */
-	public function setCreated($created) {
+	public function setCreated(\DateTime $created): Group {
 		$this->created = $created;
 
 		return $this;
@@ -78,7 +107,7 @@ class Group extends \Symfony\Component\Security\Core\Role\Role {
 	 *
 	 * @return \DateTime
 	 */
-	public function getCreated() {
+	public function getCreated(): \DateTime {
 		return $this->created;
 	}
 
@@ -87,9 +116,9 @@ class Group extends \Symfony\Component\Security\Core\Role\Role {
 	 *
 	 * @param \DateTime $updated
 	 *
-	 * @return User
+	 * @return Group
 	 */
-	public function setUpdated($updated) {
+	public function setUpdated(\DateTime $updated): Group {
 		$this->updated = $updated;
 
 		return $this;
@@ -100,18 +129,18 @@ class Group extends \Symfony\Component\Security\Core\Role\Role {
 	 *
 	 * @return \DateTime
 	 */
-	public function getUpdated() {
+	public function getUpdated(): \DateTime {
 		return $this->updated;
 	}
 
 	/**
 	 * Add user
 	 *
-	 * @param \Rapsys\UserBundle\Entity\User $user
+	 * @param User $user
 	 *
 	 * @return Group
 	 */
-	public function addUser(\Rapsys\UserBundle\Entity\User $user) {
+	public function addUser(User $user) {
 		$this->users[] = $user;
 
 		return $this;
@@ -120,18 +149,47 @@ class Group extends \Symfony\Component\Security\Core\Role\Role {
 	/**
 	 * Remove user
 	 *
-	 * @param \Rapsys\UserBundle\Entity\User $user
+	 * @param User $user
 	 */
-	public function removeUser(\Rapsys\UserBundle\Entity\User $user) {
+	public function removeUser(User $user) {
 		$this->users->removeElement($user);
 	}
 
 	/**
 	 * Get users
 	 *
-	 * @return \Doctrine\Common\Collections\Collection
+	 * @return ArrayCollection
 	 */
-	public function getUsers() {
+	public function getUsers(): ArrayCollection {
 		return $this->users;
 	}
+
+	/**
+	 * {@inheritdoc}
+	 */
+	public function preUpdate(PreUpdateEventArgs $eventArgs) {
+		//Check that we have a group instance
+		if (($user = $eventArgs->getEntity()) instanceof Group) {
+			//Set updated value
+			$user->setUpdated(new \DateTime('now'));
+		}
+	}
+
+	/**
+	 * Returns a string representation of the group
+	 *
+	 * @return string
+	 */
+	public function __toString(): string {
+		return $this->title;
+	}
+
+	/**
+	 * Get role
+	 *
+	 * @return string
+	 */
+	public function getRole(): string {
+		return 'ROLE_'.strtoupper($this->title);
+	}
 }
@@ -25,39 +41,52 @@ class Group extends \Symfony\Component\Security\Core\Role\Role {
 	/**
 	 * Constructor
-	 * @param string $role The role name
+	 *
+	 * @param string $title The group name
 	 */